==> oceanbolt.sdk-0.2.7.tar.gz: oceanbolt.sdk-0.2.7/oceanbolt/com/fleetmanagement/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from oceanbolt.com.fleetmanagement_v3.services.fleet_management_service.async_client import FleetManagementServiceAsyncClient
from oceanbolt.com.fleetmanagement_v3.services.fleet_management_service.client import FleetManagementServiceClient
from oceanbolt.com.fleetmanagement_v3.types.service import AddVesselRequest
from oceanbolt.com.fleetmanagement_v3.types.service import BatchVesselsRequest
from oceanbolt.com.fleetmanagement_v3.types.service import CreateFleetRequest
from oceanbolt.com.fleetmanagement_v3.types.service import DeleteFleetRequest
from oceanbolt.com.fleetmanagement_v3.types.service import DeleteVesselRequest
from oceanbolt.com.fleetmanagement_v3.types.service import DropVesselsRequest
from oceanbolt.com.fleetmanagement_v3.types.service import EmptyParams
from oceanbolt.com.fleetmanagement_v3.types.service import EmptyResponse
from oceanbolt.com.fleetmanagement_v3.types.service import Fleet
from oceanbolt.com.fleetmanagement_v3.types.service import Fleets
from oceanbolt.com.fleetmanagement_v3.types.service import GetFleetLiveMapRequest
from oceanbolt.com.fleetmanagement_v3.types.service import GetFleetLiveMapResponse
from oceanbolt.com.fleetmanagement_v3.types.service import GetFleetRequest
from oceanbolt.com.fleetmanagement_v3.types.service import ListVesselsRequest
from oceanbolt.com.fleetmanagement_v3.types.service import ListVesselsWithStatusRequest
from oceanbolt.com.fleetmanagement_v3.types.service import RenameFleetRequest
from oceanbolt.com.fleetmanagement_v3.types.service import ShareFleetRequest
from oceanbolt.com.fleetmanagement_v3.types.service import UpdateVesselParams
from oceanbolt.com.fleetmanagement_v3.types.service import UpdateVesselRequest
from oceanbolt.com.fleetmanagement_v3.types.service import Vessel
from oceanbolt.com.fleetmanagement_v3.types.service import VesselParams
from oceanbolt.com.fleetmanagement_v3.types.service import VesselStatus
from oceanbolt.com.fleetmanagement_v3.types.service import VesselStoppageEvent
from oceanbolt.com.fleetmanagement_v3.types.service import Vessels

__all__ = (
    'AddVesselRequest',
    'BatchVesselsRequest',
    'CreateFleetRequest',
    'DeleteFleetRequest',
    'DeleteVesselRequest',
    'DropVesselsRequest',
    'EmptyParams',
    'EmptyResponse',
    'Fleet',
    'FleetManagementServiceAsyncClient',
    'FleetManagementServiceClient',
    'Fleets',
    'GetFleetLiveMapRequest',
    'GetFleetLiveMapResponse',
    'GetFleetRequest',
    'ListVesselsRequest',
    'ListVesselsWithStatusRequest',
    'RenameFleetRequest',
    'ShareFleetRequest',
    'UpdateVesselParams',
    'UpdateVesselRequest',
    'Vessel',
    'VesselParams',
    'VesselStatus',
    'VesselStoppageEvent',
    'Vessels',
)

==> oceanbolt.sdk-0.3.0.tar.gz: oceanbolt.sdk-0.3.0/oceanbolt/com/fleetmanagement/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from oceanbolt.com.fleetmanagement_v3.services.fleet_management_service.client import FleetManagementServiceClient
from oceanbolt.com.fleetmanagement_v3.services.fleet_management_service.async_client import FleetManagementServiceAsyncClient

from oceanbolt.com.fleetmanagement_v3.types.service import AddVesselRequest
from oceanbolt.com.fleetmanagement_v3.types.service import BatchVesselsRequest
from oceanbolt.com.fleetmanagement_v3.types.service import CreateFleetRequest
from oceanbolt.com.fleetmanagement_v3.types.service import DeleteFleetRequest
from oceanbolt.com.fleetmanagement_v3.types.service import DeleteVesselRequest
from oceanbolt.com.fleetmanagement_v3.types.service import DropVesselsRequest
from oceanbolt.com.fleetmanagement_v3.types.service import EmptyParams
from oceanbolt.com.fleetmanagement_v3.types.service import EmptyResponse
from oceanbolt.com.fleetmanagement_v3.types.service import Fleet
from oceanbolt.com.fleetmanagement_v3.types.service import Fleets
from oceanbolt.com.fleetmanagement_v3.types.service import GetFleetLiveMapRequest
from oceanbolt.com.fleetmanagement_v3.types.service import GetFleetLiveMapResponse
from oceanbolt.com.fleetmanagement_v3.types.service import GetFleetRequest
from oceanbolt.com.fleetmanagement_v3.types.service import ListVesselsRequest
from oceanbolt.com.fleetmanagement_v3.types.service import ListVesselsWithStatusRequest
from oceanbolt.com.fleetmanagement_v3.types.service import RenameFleetRequest
from oceanbolt.com.fleetmanagement_v3.types.service import ShareFleetRequest
from oceanbolt.com.fleetmanagement_v3.types.service import UpdateVesselParams
from oceanbolt.com.fleetmanagement_v3.types.service import UpdateVesselRequest
from oceanbolt.com.fleetmanagement_v3.types.service import Vessel
from oceanbolt.com.fleetmanagement_v3.types.service import VesselParams
from oceanbolt.com.fleetmanagement_v3.types.service import Vessels
from oceanbolt.com.fleetmanagement_v3.types.service import VesselStatus
from oceanbolt.com.fleetmanagement_v3.types.service import VesselStoppageEvent

__all__ = ('FleetManagementServiceClient',
    'FleetManagementServiceAsyncClient',
    'AddVesselRequest',
    'BatchVesselsRequest',
    'CreateFleetRequest',
    'DeleteFleetRequest',
    'DeleteVesselRequest',
    'DropVesselsRequest',
    'EmptyParams',
    'EmptyResponse',
    'Fleet',
    'Fleets',
    'GetFleetLiveMapRequest',
    'GetFleetLiveMapResponse',
    'GetFleetRequest',
    'ListVesselsRequest',
    'ListVesselsWithStatusRequest',
    'RenameFleetRequest',
    'ShareFleetRequest',
    'UpdateVesselParams',
    'UpdateVesselRequest',
    'Vessel',
    'VesselParams',
    'Vessels',
    'VesselStatus',
    'VesselStoppageEvent',
)
